@@ -94,6 +94,7 @@ def format_constraint_evaluation(
     """
     Evaluation of the format constraint expression.
     """
+    error_message: Optional[str] = None
     if not format_constraints_expression:
         format_constraints_fulfilled = True
     else:
@@ -108,7 +109,7 @@ def format_constraint_evaluation(
             parsed_tree_fc, input_values
         )
         format_constraints_fulfilled: bool = resulting_evaluated_format_constraint_node.format_constraint_fulfilled
-        error_message: List[Optional[str]] = resulting_evaluated_format_constraint_node.error_message
+        error_message: Optional[str] = resulting_evaluated_format_constraint_node.error_message
 
     return FormatConstraintEvaluationResult(
         format_constraints_fulfilled=format_constraints_fulfilled, error_message=error_message
